# Table of Contents

- [calculations](<./calculations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Calculations](<./Calculations.md>)
  - [Overview](<./Calculations/Overview.md>)
  - [Benefits](<./Calculations/Benefits.md>)
  - [Scope](<./Calculations/Scope.md>)
  - [Limitations](<./Calculations/Limitations.md>)
  - [Technical Details](<./Calculations/Technical-Details.md>)
  - [Supported Attributes](<./Calculations/Supported-Attributes.md>)
  - [Unsupported Attributes](<./Calculations/Unsupported-Attributes.md>)
  - [Calculation Templates](<./Calculations/Calculation-Templates.md>)
  - [Activating a Calculation Template](<./Calculations/Activating-a-Calculation-Template.md>)
  - [Custom Calculations](<./Calculations/Custom-Calculations.md>)
  - [Configuring a Custom Calculation](<./Calculations/Configuring-a-Custom-Calculation.md>)
  - [Testing a Calculation](<./Calculations/Testing-a-Calculation.md>)
  - [Managing Calculations](<./Calculations/Managing-Calculations.md>)
  - [Error Handling and Validation](<./Calculations/Error-Handling-and-Validation.md>)
  - [Error Log](<./Calculations/Error-Log.md>)
  - [Code Configurations and Execution Log](<./Calculations/Code-Configurations-and-Execution-Log.md>)
  - [Processing Time](<./Calculations/Processing-Time.md>)
  - [Examples](<./Calculations/Examples.md>)
  - [Was this page helpful?](<./Calculations/Was-this-page-helpful.md>)
